diff --git a/core/includes/entity.inc b/core/includes/entity.inc
index 9dba04b..d072d99 100644
--- a/core/includes/entity.inc
+++ b/core/includes/entity.inc
@@ -536,19 +536,19 @@ function entity_get_form(EntityInterface $entity, $operation = 'default', array
 }
 
 /**
- * Returns an entity list controller for a given entity type.
+ * Returns an entity list for a given entity type.
  *
  * @param string $entity_type
  *   The type of the entity.
  *
- * @return \Drupal\Core\Entity\EntityListControllerInterface
- *   An entity list controller.
+ * @return \Drupal\Core\Entity\EntityListInterface
+ *   An entity list.
  *
  * @deprecated Use \Drupal\Core\Entity\EntityManager::getFormController().
  */
 function entity_list_controller($entity_type) {
   return \Drupal::entityManager()
-    ->getListController($entity_type);
+    ->getList($entity_type);
 }
 
 /**
diff --git a/core/includes/menu.inc b/core/includes/menu.inc
index 47e1103..d875be7 100644
--- a/core/includes/menu.inc
+++ b/core/includes/menu.inc
@@ -35,7 +35,7 @@
  * block.admin_display:
  *   path: '/admin/structure/block'
  *   defaults:
- *     _content: '\Drupal\block\Controller\BlockListController::listing'
+ *     _content: '\Drupal\block\Controller\BlockList::listing'
  *   requirements:
  *     _permission: 'administer blocks'
  * @endcode
diff --git a/core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php b/core/lib/Drupal/Core/Config/Entity/ConfigEntityList.php
similarity index 82%
rename from core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php
rename to core/lib/Drupal/Core/Config/Entity/ConfigEntityList.php
index b363cc4..1ac18e7 100644
--- a/core/lib/Drupal/Core/Config/Entity/ConfigEntityListController.php
+++ b/core/lib/Drupal/Core/Config/Entity/ConfigEntityList.php
@@ -2,21 +2,21 @@
 
 /**
  * @file
- * Definition of Drupal\Core\Config\Entity\ConfigEntityListController.
+ * Definition of Drupal\Core\Config\Entity\ConfigEntityList.
  */
 
 namespace Drupal\Core\Config\Entity;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityList;
 
 /**
- * Defines the default list controller for ConfigEntity objects.
+ * Defines the default list of configuration entities.
  */
-class ConfigEntityListController extends EntityListController {
+class ConfigEntityList extends EntityList {
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::load().
+   * {@inheritdoc}
    */
   public function load() {
     $entities = parent::load();
diff --git a/core/lib/Drupal/Core/Config/Entity/DraggableListController.php b/core/lib/Drupal/Core/Config/Entity/DraggableList.php
similarity index 94%
rename from core/lib/Drupal/Core/Config/Entity/DraggableListController.php
rename to core/lib/Drupal/Core/Config/Entity/DraggableList.php
index 5370be5..4f7477e 100644
--- a/core/lib/Drupal/Core/Config/Entity/DraggableListController.php
+++ b/core/lib/Drupal/Core/Config/Entity/DraggableList.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains Drupal\Core\Config\Entity\DraggableListController.
+ * Contains Drupal\Core\Config\Entity\DraggableList.
  */
 
 namespace Drupal\Core\Config\Entity;
@@ -13,9 +13,9 @@
 use Drupal\Core\Form\FormInterface;
 
 /**
- * Provides a list controller for draggable configuration entities.
+ * Provides a list of draggable configuration entities.
  */
-abstract class DraggableListController extends ConfigEntityListController implements FormInterface {
+abstract class DraggableList extends ConfigEntityList implements FormInterface {
 
   /**
    * The key to use for the form element containing the entities.
diff --git a/core/lib/Drupal/Core/Entity/Annotation/EntityType.php b/core/lib/Drupal/Core/Entity/Annotation/EntityType.php
index 40c1447..b18531e 100644
--- a/core/lib/Drupal/Core/Entity/Annotation/EntityType.php
+++ b/core/lib/Drupal/Core/Entity/Annotation/EntityType.php
@@ -55,7 +55,7 @@ class EntityType extends Plugin {
    *   similar. The classes must implement
    *   \Drupal\Core\Entity\EntityFormControllerInterface
    * - list: The name of the class that provides listings of the entities. The
-   *   class must implement \Drupal\Core\Entity\EntityListControllerInterface.
+   *   class must implement \Drupal\Core\Entity\EntityListInterface.
    * - render: The name of the class that is used to render the entities. The
    *   class must implement \Drupal\Core\Entity\EntityViewBuilderInterface.
    * - access: The name of the class that is used for access checks. The class
diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
index 7a07a38..bcfa972 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityListController.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Entity\Controller\EntityListController.
+ * Contains \Drupal\Core\Entity\Controller\EntityList.
  */
 
 namespace Drupal\Core\Entity\Controller;
@@ -25,7 +25,7 @@ class EntityListController extends ControllerBase {
    *   A render array as expected by drupal_render().
    */
   public function listing($entity_type) {
-    return $this->entityManager()->getListController($entity_type)->render();
+    return $this->entityManager()->getList($entity_type)->render();
   }
 
 }
diff --git a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
index f80eb51..ebff762 100644
--- a/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
+++ b/core/lib/Drupal/Core/Entity/Controller/EntityViewController.php
@@ -25,7 +25,7 @@ class EntityViewController implements ContainerInjectionInterface {
   protected $entityManager;
 
   /**
-   * Creates an EntityListController object.
+   * Creates an EntityList object.
    *
    * @param \Drupal\Core\Entity\EntityManager $entity_manager
    *   The entity manager.
diff --git a/core/lib/Drupal/Core/Entity/EntityControllerInterface.php b/core/lib/Drupal/Core/Entity/EntityControllerInterface.php
index 79232c1..f78058a 100644
--- a/core/lib/Drupal/Core/Entity/EntityControllerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityControllerInterface.php
@@ -7,7 +7,6 @@
 
 namespace Drupal\Core\Entity;
 
-use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
diff --git a/core/lib/Drupal/Core/Entity/EntityListControllerInterface.php b/core/lib/Drupal/Core/Entity/EntityListInterface.php
similarity index 85%
rename from core/lib/Drupal/Core/Entity/EntityListControllerInterface.php
rename to core/lib/Drupal/Core/Entity/EntityListInterface.php
index b7581d8..af325bb 100644
--- a/core/lib/Drupal/Core/Entity/EntityListControllerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityListInterface.php
@@ -2,21 +2,21 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Entity\EntityListControllerInterface.
+ * Contains \Drupal\Core\Entity\EntityListInterface.
  */
 
 namespace Drupal\Core\Entity;
 
 /**
- * Defines an interface for entity list controllers.
+ * Defines an interface for entity lists.
  */
-interface EntityListControllerInterface {
+interface EntityListInterface {
 
   /**
    * Gets the entity storage controller.
    *
    * @return \Drupal\Core\Entity\EntityStorageControllerInterface
-   *   The storage controller used by this list controller.
+   *   The storage controller used by this list.
    */
   public function getStorageController();
 
diff --git a/core/lib/Drupal/Core/Entity/EntityManager.php b/core/lib/Drupal/Core/Entity/EntityManager.php
index 9417884..943ac70 100644
--- a/core/lib/Drupal/Core/Entity/EntityManager.php
+++ b/core/lib/Drupal/Core/Entity/EntityManager.php
@@ -255,15 +255,15 @@ public function getStorageController($entity_type) {
   }
 
   /**
-   * Creates a new list controller instance.
+   * Creates a new list instance.
    *
    * @param string $entity_type
-   *   The entity type for this list controller.
+   *   The entity type for this list.
    *
-   * @return \Drupal\Core\Entity\EntityListControllerInterface
-   *   A list controller instance.
+   * @return \Drupal\Core\Entity\EntityListInterface
+   *   A list instance.
    */
-  public function getListController($entity_type) {
+  public function getList($entity_type) {
     if (!isset($this->controllers['listing'][$entity_type])) {
       $class = $this->getControllerClass($entity_type, 'list');
       if (in_array('Drupal\Core\Entity\EntityControllerInterface', class_implements($class))) {
diff --git a/core/modules/action/action.module b/core/modules/action/action.module
index 39fd855..b796ef8 100644
--- a/core/modules/action/action.module
+++ b/core/modules/action/action.module
@@ -63,6 +63,6 @@ function action_entity_info(&$entity_info) {
   $entity_info['action']['controllers']['form']['add'] = 'Drupal\action\ActionAddFormController';
   $entity_info['action']['controllers']['form']['edit'] = 'Drupal\action\ActionEditFormController';
   $entity_info['action']['controllers']['form']['delete'] = 'Drupal\action\Form\ActionDeleteForm';
-  $entity_info['action']['controllers']['list'] = 'Drupal\action\ActionListController';
+  $entity_info['action']['controllers']['list'] = 'Drupal\action\ActionList';
   $entity_info['action']['links']['edit-form'] = 'admin/config/system/actions/configure/{action}';
 }
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockList.php
similarity index 84%
rename from core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php
rename to core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockList.php
index efa31b3..42f371d 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockListController.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\custom_block\CustomBlockListController.
+ * Contains \Drupal\custom_block\CustomBlockList.
  */
 
 namespace Drupal\custom_block;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityList;
 
 /**
  * Provides a listing of custom block entities.
  */
-class CustomBlockListController extends EntityListController {
+class CustomBlockList extends EntityList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeList.php
similarity index 78%
rename from core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php
rename to core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeList.php
index efa4380..91d7ea3 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeListController.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/CustomBlockTypeList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\custom_block\CustomBlockTypeListController.
+ * Contains \Drupal\custom_block\CustomBlockTypeList.
  */
 
 namespace Drupal\custom_block;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of custom block types.
  */
-class CustomBlockTypeListController extends ConfigEntityListController {
+class CustomBlockTypeList extends ConfigEntityList {
 
   /**
    * {@inheritdoc}
@@ -29,7 +29,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * Overrides \Drupal\Core\Entity\EntityList::buildHeader().
    */
   public function buildHeader() {
     $header['type'] = t('Block type');
@@ -38,7 +38,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * Overrides \Drupal\Core\Entity\EntityList::buildRow().
    */
   public function buildRow(EntityInterface $entity) {
     $uri = $entity->uri();
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
index 9446451..a1207b3 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlock.php
@@ -24,7 +24,7 @@
  *   controllers = {
  *     "storage" = "Drupal\custom_block\CustomBlockStorageController",
  *     "access" = "Drupal\custom_block\CustomBlockAccessController",
- *     "list" = "Drupal\custom_block\CustomBlockListController",
+ *     "list" = "Drupal\custom_block\CustomBlockList",
  *     "view_builder" = "Drupal\custom_block\CustomBlockViewBuilder",
  *     "form" = {
  *       "add" = "Drupal\custom_block\CustomBlockFormController",
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
index c5444de..86ad242 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Entity/CustomBlockType.php
@@ -28,7 +28,7 @@
  *       "edit" = "Drupal\custom_block\CustomBlockTypeFormController",
  *       "delete" = "Drupal\custom_block\Form\CustomBlockTypeDeleteForm"
  *     },
- *     "list" = "Drupal\custom_block\CustomBlockTypeListController"
+ *     "list" = "Drupal\custom_block\CustomBlockTypeList"
  *   },
  *   admin_permission = "administer blocks",
  *   config_prefix = "custom_block.type",
diff --git a/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php b/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
index 3678a23..2f3441c 100644
--- a/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
+++ b/core/modules/block/custom_block/lib/Drupal/custom_block/Tests/CustomBlockListTest.php
@@ -12,7 +12,7 @@
 /**
  * Tests the listing of custom blocks.
  *
- * @see \Drupal\block\CustomBlockListController
+ * @see \Drupal\block\CustomBlockList
  */
 class CustomBlockListTest extends WebTestBase {
 
diff --git a/core/modules/block/lib/Drupal/block/Controller/BlockListController.php b/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
index 2852970..a040fa3 100644
--- a/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
+++ b/core/modules/block/lib/Drupal/block/Controller/BlockListController.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\block\Controller\BlockListController.
+ * Contains \Drupal\block\Controller\BlockList.
  */
 
 namespace Drupal\block\Controller;
@@ -29,7 +29,7 @@ class BlockListController extends EntityListController {
    */
   public function listing($theme = NULL, Request $request = NULL) {
     $theme = $theme ?: $this->config('system.theme')->get('default');
-    return $this->entityManager()->getListController('block')->render($theme, $request);
+    return $this->entityManager()->getList('block')->render($theme, $request);
   }
 
 }
diff --git a/core/modules/block/lib/Drupal/block/Entity/Block.php b/core/modules/block/lib/Drupal/block/Entity/Block.php
index f11031e..f195e4e 100644
--- a/core/modules/block/lib/Drupal/block/Entity/Block.php
+++ b/core/modules/block/lib/Drupal/block/Entity/Block.php
@@ -25,7 +25,7 @@
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
  *     "access" = "Drupal\block\BlockAccessController",
  *     "view_builder" = "Drupal\block\BlockViewBuilder",
- *     "list" = "Drupal\block\BlockListController",
+ *     "list" = "Drupal\block\BlockList",
  *     "form" = {
  *       "default" = "Drupal\block\BlockFormController",
  *       "delete" = "Drupal\block\Form\BlockDeleteForm"
diff --git a/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php b/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
index b26e7f2..211ab6c 100644
--- a/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
+++ b/core/modules/config/lib/Drupal/config/Tests/ConfigEntityListTest.php
@@ -32,11 +32,11 @@ public static function getInfo() {
   }
 
   /**
-   * Tests entity list controller methods.
+   * Tests entity list methods.
    */
   function testList() {
     $controller = $this->container->get('entity.manager')
-      ->getListController('config_test');
+      ->getList('config_test');
 
     // Test getStorageController() method.
     $this->assertTrue($controller->getStorageController() instanceof EntityStorageControllerInterface, 'EntityStorageController instance in storage.');
@@ -124,7 +124,7 @@ function testList() {
     // Test that config entities that do not support status, do not have
     // enable/disable operations.
     $controller = $this->container->get('entity.manager')
-      ->getListController('config_test_no_status');
+      ->getList('config_test_no_status');
 
     $list = $controller->load();
     $entity = $list['default'];
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestList.php
similarity index 68%
rename from core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php
rename to core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestList.php
index 564876a..0eafd4d 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestListController.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/ConfigTestList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\config_test\ConfigTestListController.
+ * Contains \Drupal\config_test\ConfigTestList.
  */
 
 namespace Drupal\config_test;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
- * Provides a list controller for config_test.
+ * Provides a list for config_test.
  */
-class ConfigTestListController extends ConfigEntityListController {
+class ConfigTestList extends ConfigEntityList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
index 6c55057..8f5cb6e 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigQueryTest.php
@@ -19,7 +19,7 @@
  *   module = "config_test",
  *   controllers = {
  *     "storage" = "Drupal\config_test\ConfigTestStorageController",
- *     "list" = "Drupal\Core\Config\Entity\ConfigEntityListController",
+ *     "list" = "Drupal\Core\Config\Entity\ConfigEntityList",
  *     "form" = {
  *       "default" = "Drupal\config_test\ConfigTestFormController"
  *     }
diff --git a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
index c4d330e..18a126e 100644
--- a/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
+++ b/core/modules/config/tests/config_test/lib/Drupal/config_test/Entity/ConfigTest.php
@@ -21,7 +21,7 @@
  *   module = "config_test",
  *   controllers = {
  *     "storage" = "Drupal\config_test\ConfigTestStorageController",
- *     "list" = "Drupal\config_test\ConfigTestListController",
+ *     "list" = "Drupal\config_test\ConfigTestList",
  *     "form" = {
  *       "default" = "Drupal\config_test\ConfigTestFormController",
  *       "delete" = "Drupal\config_test\Form\ConfigTestDeleteForm"
diff --git a/core/modules/contact/lib/Drupal/contact/CategoryListController.php b/core/modules/contact/lib/Drupal/contact/CategoryList.php
similarity index 75%
rename from core/modules/contact/lib/Drupal/contact/CategoryListController.php
rename to core/modules/contact/lib/Drupal/contact/CategoryList.php
index 1e62630..02bc654 100644
--- a/core/modules/contact/lib/Drupal/contact/CategoryListController.php
+++ b/core/modules/contact/lib/Drupal/contact/CategoryList.php
@@ -1,21 +1,21 @@
 <?php
 
 /**
- * Definition of Drupal\contact\CategoryListController.
+ * Definition of Drupal\contact\CategoryList.
  */
 
 namespace Drupal\contact;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of contact categories.
  */
-class CategoryListController extends ConfigEntityListController {
+class CategoryList extends ConfigEntityList {
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::buildHeader().
+   * {@inheritdoc}
    */
   public function buildHeader() {
     $header['category'] = t('Category');
@@ -25,7 +25,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides Drupal\Core\Entity\EntityListController::buildRow().
+   * {@inheritdoc}
    */
   public function buildRow(EntityInterface $entity) {
     $row['category'] = $this->getLabel($entity);
diff --git a/core/modules/contact/lib/Drupal/contact/Entity/Category.php b/core/modules/contact/lib/Drupal/contact/Entity/Category.php
index 2e6dd3b..9c7d699 100644
--- a/core/modules/contact/lib/Drupal/contact/Entity/Category.php
+++ b/core/modules/contact/lib/Drupal/contact/Entity/Category.php
@@ -23,7 +23,7 @@
  *   controllers = {
  *     "storage" = "Drupal\contact\CategoryStorageController",
  *     "access" = "Drupal\contact\CategoryAccessController",
- *     "list" = "Drupal\contact\CategoryListController",
+ *     "list" = "Drupal\contact\CategoryList",
  *     "form" = {
  *       "add" = "Drupal\contact\CategoryFormController",
  *       "edit" = "Drupal\contact\CategoryFormController",
diff --git a/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php b/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
index 1ac34da..6b10919 100644
--- a/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
+++ b/core/modules/entity/lib/Drupal/entity/Entity/EntityFormMode.php
@@ -34,7 +34,7 @@
  *   label = @Translation("Form mode"),
  *   module = "entity",
  *   controllers = {
- *     "list" = "Drupal\entity\EntityFormModeListController",
+ *     "list" = "Drupal\entity\EntityFormModeList",
  *     "form" = {
  *       "add" = "Drupal\entity\Form\EntityFormModeAddForm",
  *       "edit" = "Drupal\entity\Form\EntityDisplayModeEditForm",
diff --git a/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php b/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
index 6a4abad..9155a5f 100644
--- a/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
+++ b/core/modules/entity/lib/Drupal/entity/Entity/EntityViewMode.php
@@ -35,7 +35,7 @@
  *   label = @Translation("View mode"),
  *   module = "entity",
  *   controllers = {
- *     "list" = "Drupal\entity\EntityDisplayModeListController",
+ *     "list" = "Drupal\entity\EntityDisplayModeList",
  *     "form" = {
  *       "add" = "Drupal\entity\Form\EntityDisplayModeAddForm",
  *       "edit" = "Drupal\entity\Form\EntityDisplayModeEditForm",
diff --git a/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php b/core/modules/entity/lib/Drupal/entity/EntityDisplayModeList.php
similarity index 94%
rename from core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php
rename to core/modules/entity/lib/Drupal/entity/EntityDisplayModeList.php
index 835c1c6..bfe5893 100644
--- a/core/modules/entity/lib/Drupal/entity/EntityDisplayModeListController.php
+++ b/core/modules/entity/lib/Drupal/entity/EntityDisplayModeList.php
@@ -2,12 +2,12 @@
 
 /**
  * @file
- * Contains \Drupal\entity\EntityDisplayModeListController.
+ * Contains \Drupal\entity\EntityDisplayModeList.
  */
 
 namespace Drupal\entity;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
@@ -16,7 +16,7 @@
 /**
  * Provides the listing for entity display modes.
  */
-class EntityDisplayModeListController extends ConfigEntityListController {
+class EntityDisplayModeList extends ConfigEntityList {
 
   /**
    * The entity info for all entity types.
@@ -26,7 +26,7 @@ class EntityDisplayModeListController extends ConfigEntityListController {
   protected $entityInfoComplete;
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityList object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
diff --git a/core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php b/core/modules/entity/lib/Drupal/entity/EntityFormModeList.php
similarity index 80%
rename from core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php
rename to core/modules/entity/lib/Drupal/entity/EntityFormModeList.php
index 79417ff..b795eef 100644
--- a/core/modules/entity/lib/Drupal/entity/EntityFormModeListController.php
+++ b/core/modules/entity/lib/Drupal/entity/EntityFormModeList.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\entity\EntityFormModeListController.
+ * Contains \Drupal\entity\EntityFormModeList.
  */
 
 namespace Drupal\entity;
@@ -10,7 +10,7 @@
 /**
  * Provides the listing for entity display modes.
  */
-class EntityFormModeListController extends EntityDisplayModeListController {
+class EntityFormModeList extends EntityDisplayModeList {
 
   /**
    * Filters entities based on their controllers.
diff --git a/core/modules/field_ui/field_ui.module b/core/modules/field_ui/field_ui.module
index dc0d38f..ac67b8f 100644
--- a/core/modules/field_ui/field_ui.module
+++ b/core/modules/field_ui/field_ui.module
@@ -251,7 +251,7 @@ function field_ui_element_info() {
  */
 function field_ui_entity_info(&$entity_info) {
   $entity_info['field_instance']['controllers']['form']['delete'] = 'Drupal\field_ui\Form\FieldDeleteForm';
-  $entity_info['field_entity']['controllers']['list'] = 'Drupal\field_ui\FieldListController';
+  $entity_info['field_entity']['controllers']['list'] = 'Drupal\field_ui\FieldList';
 }
 
 /**
diff --git a/core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php b/core/modules/field_ui/lib/Drupal/field_ui/FieldList.php
similarity index 93%
rename from core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php
rename to core/modules/field_ui/lib/Drupal/field_ui/FieldList.php
index c0d3982..c64a462 100644
--- a/core/modules/field_ui/lib/Drupal/field_ui/FieldListController.php
+++ b/core/modules/field_ui/lib/Drupal/field_ui/FieldList.php
@@ -2,12 +2,12 @@
 
 /**
  * @file
- * Contains \Drupal\field_ui\FieldListController.
+ * Contains \Drupal\field_ui\FieldList.
  */
 
 namespace Drupal\field_ui;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityManager;
 use Drupal\Core\Field\FieldTypePluginManager;
@@ -17,7 +17,7 @@
 /**
  * Provides a listing of fields.
  */
-class FieldListController extends ConfigEntityListController {
+class FieldList extends ConfigEntityList {
 
   /**
    * An array of information about field types.
@@ -48,7 +48,7 @@ class FieldListController extends ConfigEntityListController {
   protected $fieldTypeManager;
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityList object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
diff --git a/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php b/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
index 59866f2..88132d2 100644
--- a/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
+++ b/core/modules/filter/lib/Drupal/filter/Entity/FilterFormat.php
@@ -27,7 +27,7 @@
  *       "edit" = "Drupal\filter\FilterFormatEditFormController",
  *       "disable" = "Drupal\filter\Form\FilterDisableForm"
  *     },
- *     "list" = "Drupal\filter\FilterFormatListController",
+ *     "list" = "Drupal\filter\FilterFormatList",
  *     "access" = "Drupal\filter\FilterFormatAccessController",
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController"
  *   },
diff --git a/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php b/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
index 42abf7c..795999c 100644
--- a/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
+++ b/core/modules/image/lib/Drupal/image/Entity/ImageStyle.php
@@ -32,7 +32,7 @@
  *       "delete" = "Drupal\image\Form\ImageStyleDeleteForm"
  *     },
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\image\ImageStyleListController",
+ *     "list" = "Drupal\image\ImageStyleList",
  *   },
  *   admin_permission = "administer image styles",
  *   config_prefix = "image.style",
diff --git a/core/modules/language/lib/Drupal/language/Entity/Language.php b/core/modules/language/lib/Drupal/language/Entity/Language.php
index c1c1006..c00a239 100644
--- a/core/modules/language/lib/Drupal/language/Entity/Language.php
+++ b/core/modules/language/lib/Drupal/language/Entity/Language.php
@@ -23,7 +23,7 @@
  *   module = "language",
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\language\LanguageListController",
+ *     "list" = "Drupal\language\LanguageList",
  *     "access" = "Drupal\language\LanguageAccessController",
  *     "form" = {
  *       "add" = "Drupal\language\Form\LanguageAddForm",
diff --git a/core/modules/language/lib/Drupal/language/LanguageListController.php b/core/modules/language/lib/Drupal/language/LanguageList.php
similarity index 93%
rename from core/modules/language/lib/Drupal/language/LanguageListController.php
rename to core/modules/language/lib/Drupal/language/LanguageList.php
index 35724b7..7f10959 100644
--- a/core/modules/language/lib/Drupal/language/LanguageListController.php
+++ b/core/modules/language/lib/Drupal/language/LanguageList.php
@@ -1,18 +1,18 @@
 <?php
 /**
  * @file
- * Contains \Drupal\language\Form\LanguageListController.
+ * Contains \Drupal\language\Form\LanguageList.
  */
 
 namespace Drupal\language;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * User interface for the language overview screen.
  */
-class LanguageListController extends DraggableListController {
+class LanguageList extends DraggableList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/menu/lib/Drupal/menu/MenuListController.php b/core/modules/menu/lib/Drupal/menu/MenuList.php
similarity index 79%
rename from core/modules/menu/lib/Drupal/menu/MenuListController.php
rename to core/modules/menu/lib/Drupal/menu/MenuList.php
index 4c5a408..84a1c30 100644
--- a/core/modules/menu/lib/Drupal/menu/MenuListController.php
+++ b/core/modules/menu/lib/Drupal/menu/MenuList.php
@@ -1,21 +1,21 @@
 <?php
 
 /**
- * Contains \Drupal\menu\MenuListController.
+ * Contains \Drupal\menu\MenuList.
  */
 
 namespace Drupal\menu;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of menus.
  */
-class MenuListController extends ConfigEntityListController {
+class MenuList extends ConfigEntityList {
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * Overrides \Drupal\Core\Entity\EntityList::buildHeader().
    */
   public function buildHeader() {
     $header['title'] = t('Title');
@@ -27,7 +27,7 @@ public function buildHeader() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * Overrides \Drupal\Core\Entity\EntityList::buildRow().
    */
   public function buildRow(EntityInterface $entity) {
     $row['title'] = array(
@@ -61,7 +61,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::render();
+   * Overrides \Drupal\Core\Entity\EntityList::render();
    */
   public function render() {
     $build = parent::render();
diff --git a/core/modules/menu/menu.module b/core/modules/menu/menu.module
index fe52570..138f0c7 100644
--- a/core/modules/menu/menu.module
+++ b/core/modules/menu/menu.module
@@ -115,7 +115,7 @@ function menu_menu() {
  * Implements hook_entity_info().
  */
 function menu_entity_info(&$entity_info) {
-  $entity_info['menu']['controllers']['list'] = 'Drupal\menu\MenuListController';
+  $entity_info['menu']['controllers']['list'] = 'Drupal\menu\MenuList';
   $entity_info['menu']['links']['edit-form'] = 'admin/structure/menu/manage/{menu}';
   $entity_info['menu']['controllers']['form'] = array(
     'add' => 'Drupal\menu\MenuFormController',
diff --git a/core/modules/node/lib/Drupal/node/Entity/NodeType.php b/core/modules/node/lib/Drupal/node/Entity/NodeType.php
index 5bc423e..16a0e34 100644
--- a/core/modules/node/lib/Drupal/node/Entity/NodeType.php
+++ b/core/modules/node/lib/Drupal/node/Entity/NodeType.php
@@ -28,7 +28,7 @@
  *       "edit" = "Drupal\node\NodeTypeFormController",
  *       "delete" = "Drupal\node\Form\NodeTypeDeleteConfirm"
  *     },
- *     "list" = "Drupal\node\NodeTypeListController",
+ *     "list" = "Drupal\node\NodeTypeList",
  *   },
  *   admin_permission = "administer content types",
  *   config_prefix = "node.type",
diff --git a/core/modules/node/lib/Drupal/node/NodeTypeListController.php b/core/modules/node/lib/Drupal/node/NodeTypeList.php
similarity index 92%
rename from core/modules/node/lib/Drupal/node/NodeTypeListController.php
rename to core/modules/node/lib/Drupal/node/NodeTypeList.php
index 0cb406f..357fc47 100644
--- a/core/modules/node/lib/Drupal/node/NodeTypeListController.php
+++ b/core/modules/node/lib/Drupal/node/NodeTypeList.php
@@ -1,13 +1,12 @@
 <?php
 
 /**
- * Contains \Drupal\node\NodeTypeListController.
+ * Contains \Drupal\node\NodeTypeList.
  */
 
 namespace Drupal\node;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
@@ -19,7 +18,7 @@
 /**
  * Provides a listing of node types.
  */
-class NodeTypeListController extends ConfigEntityListController implements EntityControllerInterface {
+class NodeTypeList extends ConfigEntityList {
 
   /**
    * The url generator service.
diff --git a/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php b/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
index c5a6e98..b35f20d 100644
--- a/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
+++ b/core/modules/picture/lib/Drupal/picture/Entity/PictureMapping.php
@@ -21,7 +21,7 @@
  *   module = "picture",
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
- *     "list" = "Drupal\picture\PictureMappingListController",
+ *     "list" = "Drupal\picture\PictureMappingList",
  *     "form" = {
  *       "edit" = "Drupal\picture\PictureMappingFormController",
  *       "add" = "Drupal\picture\PictureMappingFormController",
diff --git a/core/modules/picture/lib/Drupal/picture/PictureMappingListController.php b/core/modules/picture/lib/Drupal/picture/PictureMappingList.php
similarity index 83%
rename from core/modules/picture/lib/Drupal/picture/PictureMappingListController.php
rename to core/modules/picture/lib/Drupal/picture/PictureMappingList.php
index ffe4c0c..7fad7ff 100644
--- a/core/modules/picture/lib/Drupal/picture/PictureMappingListController.php
+++ b/core/modules/picture/lib/Drupal/picture/PictureMappingList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains Drupal\picture\PictureListController.
+ * Contains Drupal\picture\PictureList.
  */
 
 namespace Drupal\picture;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of Pictures.
  */
-class PictureMappingListController extends ConfigEntityListController {
+class PictureMappingList extends ConfigEntityList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php b/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
index b52fccb..05e84e0 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/Entity/ShortcutSet.php
@@ -23,7 +23,7 @@
  *   controllers = {
  *     "storage" = "Drupal\shortcut\ShortcutSetStorageController",
  *     "access" = "Drupal\shortcut\ShortcutSetAccessController",
- *     "list" = "Drupal\shortcut\ShortcutSetListController",
+ *     "list" = "Drupal\shortcut\ShortcutSetList",
  *     "form" = {
  *       "default" = "Drupal\shortcut\ShortcutSetFormController",
  *       "add" = "Drupal\shortcut\ShortcutSetFormController",
diff --git a/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php b/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetList.php
similarity index 73%
rename from core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php
rename to core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetList.php
index 6215a87..4455085 100644
--- a/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetListController.php
+++ b/core/modules/shortcut/lib/Drupal/shortcut/ShortcutSetList.php
@@ -2,21 +2,21 @@
 
 /**
  * @file
- * Contains \Drupal\shortcut\ShortcutSetListController.
+ * Contains \Drupal\shortcut\ShortcutSetList.
  */
 
 namespace Drupal\shortcut;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of shortcut sets.
  */
-class ShortcutSetListController extends ConfigEntityListController {
+class ShortcutSetList extends ConfigEntityList {
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildHeader().
+   * Overrides \Drupal\Core\Entity\EntityList::buildHeader().
    */
   public function buildHeader() {
     $header['name'] = t('Name');
@@ -43,7 +43,7 @@ public function getOperations(EntityInterface $entity) {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::buildRow().
+   * Overrides \Drupal\Core\Entity\EntityList::buildRow().
    */
   public function buildRow(EntityInterface $entity) {
     $row['name'] = $this->getLabel($entity);
diff --git a/core/modules/system/lib/Drupal/system/Entity/DateFormat.php b/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
index 54e58d8..d3528ba 100644
--- a/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
+++ b/core/modules/system/lib/Drupal/system/Entity/DateFormat.php
@@ -24,7 +24,7 @@
  *   controllers = {
  *     "storage" = "Drupal\Core\Config\Entity\ConfigStorageController",
  *     "access" = "Drupal\system\DateFormatAccessController",
- *     "list" = "Drupal\system\DateFormatListController",
+ *     "list" = "Drupal\system\DateFormatList",
  *     "form" = {
  *       "add" = "Drupal\system\Form\DateFormatAddForm",
  *       "edit" = "Drupal\system\Form\DateFormatEditForm",
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
index 531d6d6..0d24eb1 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/Entity/EntityTest.php
@@ -21,7 +21,7 @@
  *   module = "entity_test",
  *   controllers = {
  *     "storage" = "Drupal\entity_test\EntityTestStorageController",
- *     "list" = "Drupal\entity_test\EntityTestListController",
+ *     "list" = "Drupal\entity_test\EntityTestList",
  *     "view_builder" = "Drupal\entity_test\EntityTestViewBuilder",
  *     "access" = "Drupal\entity_test\EntityTestAccessController",
  *     "form" = {
diff --git a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestList.php
similarity index 70%
rename from core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php
rename to core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestList.php
index fddc724..7705de7 100644
--- a/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestListController.php
+++ b/core/modules/system/tests/modules/entity_test/lib/Drupal/entity_test/EntityTestList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\entity_test\EntityTestListController.
+ * Contains \Drupal\entity_test\EntityTestList.
  */
 
 namespace Drupal\entity_test;
 
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Entity\EntityListController;
+use Drupal\Core\Entity\EntityList;
 
 /**
- * Provides a list controller for entity_test.
+ * Provides a list for entity_test.
  */
-class EntityTestListController extends EntityListController {
+class EntityTestList extends EntityList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
index 721d5ea..a085480 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/Entity/Vocabulary.php
@@ -22,7 +22,7 @@
  *   module = "taxonomy",
  *   controllers = {
  *     "storage" = "Drupal\taxonomy\VocabularyStorageController",
- *     "list" = "Drupal\taxonomy\VocabularyListController",
+ *     "list" = "Drupal\taxonomy\VocabularyList",
  *     "form" = {
  *       "default" = "Drupal\taxonomy\VocabularyFormController",
  *       "reset" = "Drupal\taxonomy\Form\VocabularyResetForm",
diff --git a/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php b/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyList.php
similarity index 93%
rename from core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php
rename to core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyList.php
index bcf7877..e4326c8 100644
--- a/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyListController.php
+++ b/core/modules/taxonomy/lib/Drupal/taxonomy/VocabularyList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\taxonomy\VocabularyListController.
+ * Contains \Drupal\taxonomy\VocabularyList.
  */
 
 namespace Drupal\taxonomy;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of vocabularies.
  */
-class VocabularyListController extends DraggableListController {
+class VocabularyList extends DraggableList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/user/lib/Drupal/user/Controller/UserAdmin.php b/core/modules/user/lib/Drupal/user/Controller/UserAdmin.php
index c5da477..d1583c1 100644
--- a/core/modules/user/lib/Drupal/user/Controller/UserAdmin.php
+++ b/core/modules/user/lib/Drupal/user/Controller/UserAdmin.php
@@ -18,7 +18,7 @@
 /**
  * Provides a user administrative listing.
  *
- * @todo Convert this to a entity list controller once table sort is supported.
+ * @todo Convert this to a entity list once table sort is supported.
  */
 class UserAdmin extends ControllerBase implements ContainerInjectionInterface {
 
diff --git a/core/modules/user/lib/Drupal/user/Entity/Role.php b/core/modules/user/lib/Drupal/user/Entity/Role.php
index 5bb6631..a962741 100644
--- a/core/modules/user/lib/Drupal/user/Entity/Role.php
+++ b/core/modules/user/lib/Drupal/user/Entity/Role.php
@@ -21,7 +21,7 @@
  *   controllers = {
  *     "storage" = "Drupal\user\RoleStorageController",
  *     "access" = "Drupal\user\RoleAccessController",
- *     "list" = "Drupal\user\RoleListController",
+ *     "list" = "Drupal\user\RoleList",
  *     "form" = {
  *       "default" = "Drupal\user\RoleFormController",
  *       "delete" = "Drupal\user\Form\UserRoleDelete"
diff --git a/core/modules/user/lib/Drupal/user/RoleListController.php b/core/modules/user/lib/Drupal/user/RoleList.php
similarity index 89%
rename from core/modules/user/lib/Drupal/user/RoleListController.php
rename to core/modules/user/lib/Drupal/user/RoleList.php
index 4aa4f52..a8475ef 100644
--- a/core/modules/user/lib/Drupal/user/RoleListController.php
+++ b/core/modules/user/lib/Drupal/user/RoleList.php
@@ -2,18 +2,18 @@
 
 /**
  * @file
- * Contains \Drupal\user\RoleListController.
+ * Contains \Drupal\user\RoleList.
  */
 
 namespace Drupal\user;
 
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableList;
 use Drupal\Core\Entity\EntityInterface;
 
 /**
  * Provides a listing of user roles.
  */
-class RoleListController extends DraggableListController {
+class RoleList extends DraggableList {
 
   /**
    * {@inheritdoc}
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
index 5995f65..ed508e8 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/Controller/ViewsUIController.php
@@ -194,7 +194,7 @@ public function ajaxOperation(ViewStorageInterface $view, $op, Request $request)
 
     // If the request is via AJAX, return the rendered list as JSON.
     if ($request->request->get('js')) {
-      $list = $this->entityManager->getListController('view')->render();
+      $list = $this->entityManager->getList('view')->render();
       $response = new AjaxResponse();
       $response->addCommand(new ReplaceCommand('#views-entity-list', drupal_render($list)));
       return $response;
diff --git a/core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php b/core/modules/views_ui/lib/Drupal/views_ui/ViewList.php
similarity index 96%
rename from core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php
rename to core/modules/views_ui/lib/Drupal/views_ui/ViewList.php
index d2029fe..5426b76 100644
--- a/core/modules/views_ui/lib/Drupal/views_ui/ViewListController.php
+++ b/core/modules/views_ui/lib/Drupal/views_ui/ViewList.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\views_ui\ViewListController.
+ * Contains \Drupal\views_ui\ViewList.
  */
 
 namespace Drupal\views_ui;
@@ -10,8 +10,7 @@
 use Drupal\Component\Utility\String;
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -19,7 +18,7 @@
 /**
  * Provides a listing of Views.
  */
-class ViewListController extends ConfigEntityListController implements EntityControllerInterface {
+class ViewList extends ConfigEntityList {
 
   /**
    * The views display plugin manager to use.
@@ -42,7 +41,7 @@ public static function createInstance(ContainerInterface $container, $entity_typ
   }
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityList object.
    *
    * @param string $entity_type.
    *   The type of entity to be listed.
diff --git a/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php b/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListTest.php
similarity index 93%
rename from core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php
rename to core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListTest.php
index 470568b..47d5fb7 100644
--- a/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListControllerTest.php
+++ b/core/modules/views_ui/tests/Drupal/views_ui/Tests/ViewListTest.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\views_ui\Tests\ViewListControllerTest
+ * Contains \Drupal\views_ui\Tests\ViewListTest
  */
 
 namespace Drupal\views_ui\Tests {
@@ -13,12 +13,12 @@
 use Drupal\views\Entity\View;
 use Drupal\views\ViewExecutableFactory;
 
-class ViewListControllerTest extends UnitTestCase {
+class ViewListTest extends UnitTestCase {
 
   public static function getInfo() {
     return array(
       'name' => 'Views List Controller Unit Test',
-      'description' => 'Unit tests the views list controller',
+      'description' => 'Unit tests the views list',
       'group' => 'Views UI',
     );
   }
@@ -26,7 +26,7 @@ public static function getInfo() {
   /**
    * Tests the listing of displays on a views list.
    *
-   * @see \Drupal\views_ui\ViewListController::getDisplaysList().
+   * @see \Drupal\views_ui\ViewList::getDisplaysList()
    */
   public function testBuildRowEntityList() {
     $storage_controller = $this->getMockBuilder('Drupal\views\ViewStorageController')
@@ -124,7 +124,7 @@ public function testBuildRowEntityList() {
       ->disableOriginalConstructor()
       ->getMock();
 
-    // Setup a view list controller with a mocked buildOperations method,
+    // Setup a view list with a mocked buildOperations method,
     // because t() is called on there.
     $view_list_controller = $this->getMock('Drupal\views_ui\ViewListController', array('buildOperations'), array('view', $storage_controller, $entity_info, $display_manager, $module_handler));
     $view_list_controller->expects($this->any())
diff --git a/core/modules/views_ui/views_ui.module b/core/modules/views_ui/views_ui.module
index 93742a4..6f64869 100644
--- a/core/modules/views_ui/views_ui.module
+++ b/core/modules/views_ui/views_ui.module
@@ -51,7 +51,7 @@ function views_ui_menu() {
  */
 function views_ui_entity_info(&$entity_info) {
   $entity_info['view']['controllers'] += array(
-    'list' => 'Drupal\views_ui\ViewListController',
+    'list' => 'Drupal\views_ui\ViewList',
     'form' => array(
       'edit' => 'Drupal\views_ui\ViewEditFormController',
       'add' => 'Drupal\views_ui\ViewAddFormController',
diff --git a/core/tests/Drupal/Tests/Core/Entity/Enhancer/EntityRouteEnhancerTest.php b/core/tests/Drupal/Tests/Core/Entity/Enhancer/EntityRouteEnhancerTest.php
index 17f454e..2ec6782 100644
--- a/core/tests/Drupal/Tests/Core/Entity/Enhancer/EntityRouteEnhancerTest.php
+++ b/core/tests/Drupal/Tests/Core/Entity/Enhancer/EntityRouteEnhancerTest.php
@@ -55,12 +55,12 @@ public function testEnhancer() {
     $defaults = $route_enhancer->enhance($defaults, $request);
     $this->assertEquals('\Drupal\Core\Entity\HtmlEntityFormController::content', $defaults['_controller'], 'The entity form controller was not set.');
 
-    // Set _entity_list and ensure that the entity list controller is set.
+    // Set _entity_list and ensure that the entity list is set.
     $defaults = array();
     $defaults['_entity_list'] = 'entity_test.default';
     $defaults = $route_enhancer->enhance($defaults, $request);
     $this->assertEquals('controller.page:content', $defaults['_controller']);
-    $this->assertEquals('\Drupal\Core\Entity\Controller\EntityListController::listing', $defaults['_content'], 'The entity list controller was not set.');
+    $this->assertEquals('\Drupal\Core\Entity\Controller\EntityListController::listing', $defaults['_content'], 'The entity list was not set.');
     $this->assertEquals('entity_test.default', $defaults['entity_type']);
     $this->assertFalse(isset($defaults['_entity_list']));
 
diff --git a/core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php b/core/tests/Drupal/Tests/Core/Entity/EntityListTest.php
similarity index 79%
rename from core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php
rename to core/tests/Drupal/Tests/Core/Entity/EntityListTest.php
index c8b07d6..e661526 100644
--- a/core/tests/Drupal/Tests/Core/Entity/EntityListControllerTest.php
+++ b/core/tests/Drupal/Tests/Core/Entity/EntityListTest.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Tests\Core\Entity\EntityListControllerTest.
+ * Contains \Drupal\Tests\Core\Entity\EntityListTest.
  */
 
 namespace Drupal\Tests\Core\Entity;
@@ -10,31 +10,31 @@
 use Drupal\Tests\UnitTestCase;
 
 /**
- * Tests the entity list controller.
+ * Tests the entity list.
  *
  * @group Entity
  *
- * @see \Drupal\entity_test\EntityTestListController
+ * @see \Drupal\entity_test\EntityTestList
  */
-class EntityListControllerTest extends UnitTestCase {
+class EntityListTest extends UnitTestCase {
 
   /**
-   * The entity used to construct the EntityListController.
+   * The entity used to construct the EntityList.
    *
    * @var \Drupal\user\Entity\Role
    */
   protected $role;
 
   /**
-   * The EntityListController object to test.
+   * The EntityList object to test.
    *
-   * @var \Drupal\Core\Entity\EntityListController
+   * @var \Drupal\Core\Entity\EntityList
    */
   protected $entityListController;
 
   public static function getInfo() {
     return array(
-      'name' => 'Entity list controller test',
+      'name' => 'Entity list test',
       'description' => 'Unit test of entity access checking system.',
       'group' => 'Entity'
     );
@@ -132,13 +132,13 @@ public function testBuildRow($input, $expected, $message, $ignorewarnings = FALS
   public function providerTestBuildRow() {
     $tests = array();
     // Checks that invalid multi-byte sequences are rejected.
-    $tests[] = array("Foo\xC0barbaz", '', 'EntityTestListController::buildRow() rejects invalid sequence "Foo\xC0barbaz"', TRUE);
-    $tests[] = array("\xc2\"", '', 'EntityTestListController::buildRow() rejects invalid sequence "\xc2\""', TRUE);
-    $tests[] = array("Fooÿñ", "Fooÿñ", 'EntityTestListController::buildRow() accepts valid sequence "Fooÿñ"');
+    $tests[] = array("Foo\xC0barbaz", '', 'EntityTestList::buildRow() rejects invalid sequence "Foo\xC0barbaz"', TRUE);
+    $tests[] = array("\xc2\"", '', 'EntityTestList::buildRow() rejects invalid sequence "\xc2\""', TRUE);
+    $tests[] = array("Fooÿñ", "Fooÿñ", 'EntityTestList::buildRow() accepts valid sequence "Fooÿñ"');
 
     // Checks that special characters are escaped.
-    $tests[] = array("<script>", '&lt;script&gt;', 'EntityTestListController::buildRow() escapes &lt;script&gt;');
-    $tests[] = array('<>&"\'', '&lt;&gt;&amp;&quot;&#039;', 'EntityTestListController::buildRow() escapes reserved HTML characters.');
+    $tests[] = array("<script>", '&lt;script&gt;', 'EntityTestList::buildRow() escapes &lt;script&gt;');
+    $tests[] = array('<>&"\'', '&lt;&gt;&amp;&quot;&#039;', 'EntityTestList::buildRow() escapes reserved HTML characters.');
 
     return $tests;
 

diff --git a/core/lib/Drupal/Core/Entity/EntityListController.php b/core/lib/Drupal/Core/Entity/EntityList.php
similarity index 89%
rename from core/lib/Drupal/Core/Entity/EntityListController.php
rename to core/lib/Drupal/Core/Entity/EntityList.php
index 7312e3f..060efa5 100644
--- a/core/lib/Drupal/Core/Entity/EntityListController.php
+++ b/core/lib/Drupal/Core/Entity/EntityList.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\Core\Entity\EntityListController.
+ * Contains \Drupal\Core\Entity\EntityList.
  */
 
 namespace Drupal\Core\Entity;
@@ -13,9 +13,9 @@
 use Drupal\Component\Utility\String;
 
 /**
- * Provides a generic implementation of an entity list controller.
+ * Provides a generic implementation of an entity list.
  */
-class EntityListController implements EntityListControllerInterface, EntityControllerInterface {
+class EntityList implements EntityListInterface, EntityControllerInterface {
 
   /**
    * The entity storage controller class.
@@ -67,7 +67,7 @@ public static function createInstance(ContainerInterface $container, $entity_typ
   }
 
   /**
    * Constructs a new EntityListController object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
@@ -86,14 +86,14 @@ public function __construct($entity_type, array $entity_info, EntityStorageContr
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::getStorageController().
+   * {@inheritdoc}
    */
   public function getStorageController() {
     return $this->storage;
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::load().
+   * {@inheritdoc}
    */
   public function load() {
     return $this->storage->loadMultiple();
@@ -145,7 +145,7 @@ public function getOperations(EntityInterface $entity) {
    * @return array
    *   A render array structure of header strings.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityList::render()
    */
   public function buildHeader() {
     $row['operations'] = t('Operations');
@@ -161,7 +161,7 @@ public function buildHeader() {
    * @return array
    *   A render array structure of fields for this entity.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityList::render()
    */
   public function buildRow(EntityInterface $entity) {
     $row['operations']['data'] = $this->buildOperations($entity);
@@ -177,7 +177,7 @@ public function buildRow(EntityInterface $entity) {
    * @return array
    *   A renderable array of operation links.
    *
-   * @see \Drupal\Core\Entity\EntityListController::render()
+   * @see \Drupal\Core\Entity\EntityList::render()
    */
   public function buildOperations(EntityInterface $entity) {
     // Retrieve and sort operations.
@@ -192,7 +192,7 @@ public function buildOperations(EntityInterface $entity) {
   }
 
   /**
-   * Implements \Drupal\Core\Entity\EntityListControllerInterface::render().
+   * {@inheritdoc}
    *
    * Builds the entity list as renderable array for theme_table().
    *
@@ -67,7 +67,7 @@ public static function createInstance(ContainerInterface $container, $entity_typ
 
   /**
-   * Constructs a new EntityListController object.
+   * Constructs a new EntityList object.
    *
    * @param string $entity_type
diff --git a/core/modules/action/lib/Drupal/action/ActionListController.php b/core/modules/action/lib/Drupal/action/ActionList.php
similarity index 91%
rename from core/modules/action/lib/Drupal/action/ActionListController.php
rename to core/modules/action/lib/Drupal/action/ActionList.php
index 405f224..536a6aa 100644
--- a/core/modules/action/lib/Drupal/action/ActionListController.php
+++ b/core/modules/action/lib/Drupal/action/ActionList.php
@@ -2,15 +2,14 @@
 
 /**
  * @file
- * Contains \Drupal\action\ActionListController.
+ * Contains \Drupal\action\ActionList.
  */
 
 namespace Drupal\action;
 
 use Drupal\Core\Action\ActionManager;
-use Drupal\Core\Entity\EntityControllerInterface;
 use Drupal\Core\Entity\EntityInterface;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
@@ -18,7 +17,7 @@
 /**
  * Provides a listing of Actions.
  */
-class ActionListController extends ConfigEntityListController implements EntityControllerInterface {
+class ActionList extends ConfigEntityList {
 
   /**
    * @var bool
@@ -33,7 +32,7 @@ class ActionListController extends ConfigEntityListController implements EntityC
   protected $actionManager;
 
   /**
    * Constructs a new ActionListController object.
    *
    * @param string $entity_type
    *   The entity type.
@@ -33,7 +32,7 @@ class ActionListController extends ConfigEntityListController implements EntityC
 
   /**
-   * Constructs a new ActionListController object.
+   * Constructs a new ActionList object.
    *
    * @param string $entity_type
diff --git a/core/modules/block/lib/Drupal/block/BlockListController.php b/core/modules/block/lib/Drupal/block/BlockList.php
similarity index 96%
rename from core/modules/block/lib/Drupal/block/BlockListController.php
rename to core/modules/block/lib/Drupal/block/BlockList.php
index 874ff35..1da4b59 100644
--- a/core/modules/block/lib/Drupal/block/BlockListController.php
+++ b/core/modules/block/lib/Drupal/block/BlockList.php
@@ -2,7 +2,7 @@
 
 /**
  * @file
- * Contains \Drupal\block\BlockListController.
+ * Contains \Drupal\block\BlockList.
  */
 
 namespace Drupal\block;
@@ -10,8 +10,7 @@
 use Drupal\Component\Plugin\PluginManagerInterface;
 use Drupal\Component\Utility\Json;
 use Drupal\Component\Utility\String;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
@@ -20,9 +19,9 @@
 use Symfony\Component\HttpFoundation\Request;
 
 /**
- * Defines the block list controller.
+ * Defines the block list.
  */
-class BlockListController extends ConfigEntityListController implements FormInterface, EntityControllerInterface {
+class BlockList extends ConfigEntityList implements FormInterface {
 
   /**
    * The regions containing the blocks.
@@ -53,7 +52,7 @@ class BlockListController extends ConfigEntityListController implements FormInte
   protected $blockManager;
 
   /**
    * Constructs a new BlockListController object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
@@ -86,7 +85,7 @@ public static function createInstance(ContainerInterface $container, $entity_typ
   }
 
   /**
-   * Overrides \Drupal\Core\Config\Entity\ConfigEntityListController::load().
+   * Overrides \Drupal\Core\Config\Entity\ConfigEntityList::load().
    */
   public function load() {
     // If no theme was specified, use the current theme.
@@ -107,7 +106,7 @@ public function load() {
   }
 
   /**
-   * Overrides \Drupal\Core\Entity\EntityListController::render().
+   * Overrides \Drupal\Core\Entity\EntityList::render().
    *
    * @param string|null $theme
    *   (optional) The theme to display the blocks for. If NULL, the current
@@ -53,7 +52,7 @@ class BlockListController extends ConfigEntityListController implements FormInte
 
   /**
-   * Constructs a new BlockListController object.
+   * Constructs a new BlockList object.
    *
    * @param string $entity_type
diff --git a/core/modules/filter/lib/Drupal/filter/FilterFormatListController.php b/core/modules/filter/lib/Drupal/filter/FilterFormatList.php
similarity index 93%
rename from core/modules/filter/lib/Drupal/filter/FilterFormatListController.php
rename to core/modules/filter/lib/Drupal/filter/FilterFormatList.php
index cd94f86..e752ec2 100644
--- a/core/modules/filter/lib/Drupal/filter/FilterFormatListController.php
+++ b/core/modules/filter/lib/Drupal/filter/FilterFormatList.php
@@ -2,14 +2,14 @@
 
 /**
  * @file
- * Contains \Drupal\filter\FilterFormatListController.
+ * Contains \Drupal\filter\FilterFormatList.
  */
 
 namespace Drupal\filter;
 
 use Drupal\Component\Utility\String;
 use Drupal\Core\Config\ConfigFactory;
-use Drupal\Core\Config\Entity\DraggableListController;
+use Drupal\Core\Config\Entity\DraggableList;
 use Drupal\Core\Entity\EntityControllerInterface;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
@@ -17,9 +17,9 @@
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
- * Defines the filter format list controller.
+ * Defines the filter format list.
  */
-class FilterFormatListController extends DraggableListController implements EntityControllerInterface {
+class FilterFormatList extends DraggableList implements EntityControllerInterface {
 
   /**
    * {@inheritdoc}
@@ -34,7 +34,7 @@ class FilterFormatListController extends DraggableListController implements Enti
   protected $configFactory;
 
   /**
    * Constructs a new FilterFormatListController.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
@@ -34,7 +34,7 @@ class FilterFormatListController extends DraggableListController implements Enti
 
   /**
-   * Constructs a new FilterFormatListController.
+   * Constructs a new FilterFormatList.
    *
    * @param string $entity_type
diff --git a/core/modules/image/lib/Drupal/image/ImageStyleListController.php b/core/modules/image/lib/Drupal/image/ImageStyleList.php
similarity index 88%
rename from core/modules/image/lib/Drupal/image/ImageStyleListController.php
rename to core/modules/image/lib/Drupal/image/ImageStyleList.php
index 984fe89..f340bf6 100644
--- a/core/modules/image/lib/Drupal/image/ImageStyleListController.php
+++ b/core/modules/image/lib/Drupal/image/ImageStyleList.php
@@ -2,13 +2,12 @@
 
 /**
  * @file
- * Contains \Drupal\image\ImageStyleListController.
+ * Contains \Drupal\image\ImageStyleList.
  */
 
 namespace Drupal\image;
 
-use Drupal\Core\Config\Entity\ConfigEntityListController;
-use Drupal\Core\Entity\EntityControllerInterface;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
@@ -19,7 +18,7 @@
 /**
  * Provides a listing of image styles.
  */
-class ImageStyleListController extends ConfigEntityListController implements EntityControllerInterface {
+class ImageStyleList extends ConfigEntityList {
 
   /**
    * The URL generator.
@@ -29,7 +28,7 @@ class ImageStyleListController extends ConfigEntityListController implements Ent
   protected $urlGenerator;
 
   /**
    * Constructs a new ImageStyleListController object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
@@ -29,7 +28,7 @@ class ImageStyleListController extends ConfigEntityListController implements Ent
 
   /**
-   * Constructs a new ImageStyleListController object.
+   * Constructs a new ImageStyleList object.
    *
    * @param string $entity_type
diff --git a/core/modules/system/lib/Drupal/system/DateFormatListController.php b/core/modules/system/lib/Drupal/system/DateFormatList.php
similarity index 90%
rename from core/modules/system/lib/Drupal/system/DateFormatListController.php
rename to core/modules/system/lib/Drupal/system/DateFormatList.php
index d22642b..6ca36b2 100644
--- a/core/modules/system/lib/Drupal/system/DateFormatListController.php
+++ b/core/modules/system/lib/Drupal/system/DateFormatList.php
@@ -2,13 +2,13 @@
 
 /**
  * @file
- * Contains \Drupal\system\DateFormatListController.
+ * Contains \Drupal\system\DateFormatList.
  */
 
 namespace Drupal\system;
 
 use Drupal\Component\Utility\String;
-use Drupal\Core\Config\Entity\ConfigEntityListController;
+use Drupal\Core\Config\Entity\ConfigEntityList;
 use Drupal\Core\Datetime\Date;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageControllerInterface;
@@ -18,7 +18,7 @@
 /**
  * Provides a listing of date formats.
  */
-class DateFormatListController extends ConfigEntityListController {
+class DateFormatList extends ConfigEntityList {
 
   /**
    * The date service.
@@ -28,7 +28,7 @@ class DateFormatListController extends ConfigEntityListController {
   protected $dateService;
 
   /**
    * Constructs a new DateFormatListController object.
    *
    * @param string $entity_type
    *   The type of entity to be listed.
@@ -28,7 +28,7 @@ class DateFormatListController extends ConfigEntityListController {
 
   /**
-   * Constructs a new DateFormatListController object.
+   * Constructs a new DateFormatList object.
    *
    * @param string $entity_type